@@ -1,22 +1,9 @@
 /*
     This file is part of the KDE libraries
 
-    Copyright (C) 2007 Oswald Buddenhagen <ossi@kde.org>
+    SPDX-FileCopyrightText: 2007 Oswald Buddenhagen <ossi@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kprocess_p.h"
@@ -37,9 +24,8 @@
 
 KProcess::KProcess(QObject *parent) :
     QProcess(parent),
-    d_ptr(new KProcessPrivate)
+    d_ptr(new KProcessPrivate(this))
 {
-    d_ptr->q_ptr = this;
     setOutputChannelMode(ForwardedChannels);
 }
 
@@ -77,7 +63,7 @@ void KProcess::setNextOpenMode(QIODevice::OpenMode mode)
 
 void KProcess::clearEnvironment()
 {
-    setEnvironment(QStringList() << QStringLiteral(DUMMYENV));
+    setEnvironment(QStringList { QStringLiteral(DUMMYENV) });
 }
 
 void KProcess::setEnv(const QString &name, const QString &value, bool overwrite)
@@ -201,7 +187,7 @@ void KProcess::setShellCommand(const QString &cmd)
 
 #ifdef Q_OS_UNIX
 // #ifdef NON_FREE // ... as they ship non-POSIX /bin/sh
-# if !defined(__linux__) && !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__DragonFly__) && !defined(__GNU__)
+# if !defined(__linux__) && !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__DragonFly__) && !defined(__GNU__) && !defined(__APPLE__)
     // If /bin/sh is a symlink, we can be pretty sure that it points to a
     // POSIX shell - the original bourne shell is about the only non-POSIX
     // shell still in use and it is always installed natively as /bin/sh.
@@ -239,7 +225,7 @@ void KProcess::setShellCommand(const QString &cmd)
     UINT size = GetSystemDirectoryW(sysdir, MAX_PATH + 1);
     d->prog = QString::fromUtf16((const ushort *) sysdir, size);
     d->prog += QLatin1String("\\cmd.exe");
-    setNativeArguments(QStringLiteral("/V:OFF /S /C \"") + cmd + QLatin1Char('"'));
+    setNativeArguments(QLatin1String("/V:OFF /S /C \"") + cmd + QLatin1Char('"'));
 #else
     d->prog = QStringLiteral("\\windows\\cmd.exe");
     setNativeArguments(QStringLiteral("/S /C \"") + cmd + QLatin1Char('"'));
